---
sidebar_position: 6
---

# Experimental Plan Subgraph

This page explains the details of the Experimental Plan Subgraph.

## Overview

The Experimental Plan Subgraph is a component responsible for formulating experimental plans.

## Features

- Main feature 1
- Main feature 2
- Main feature 3

## Usage

```python
# Example usage of Experimental Plan Subgraph
from researchgraph.experimental_plan_subgraph.experimental_plan_subgraph import ExperimentalPlaner

experimentalplaner = ExperimentalPlaner(
    github_repository=github_repository,
    branch_name=branch_name,
)

result = experimentalplaner.run()
print(f"result: {result}")
```

## API

Details about the API provided by the Experimental Plan Subgraph are under preparation.
